pub struct BootstrapLiquidity<'info> {Show 16 fields
pub pool: Box<Account<'info, Pool>>,
pub lp_mint: Account<'info, Mint>,
pub user_pool_lp: Account<'info, TokenAccount>,
pub a_vault_lp: Box<Account<'info, TokenAccount>>,
pub b_vault_lp: Box<Account<'info, TokenAccount>>,
pub a_vault: Box<Account<'info, Vault>>,
pub b_vault: Box<Account<'info, Vault>>,
pub a_vault_lp_mint: Box<Account<'info, Mint>>,
pub b_vault_lp_mint: Box<Account<'info, Mint>>,
pub a_token_vault: Box<Account<'info, TokenAccount>>,
pub b_token_vault: Box<Account<'info, TokenAccount>>,
pub user_a_token: Account<'info, TokenAccount>,
pub user_b_token: Account<'info, TokenAccount>,
pub user: Signer<'info>,
pub vault_program: Program<'info, MercurialVault>,
pub token_program: Program<'info, Token>,
}Expand description
Bootstrap pool with zero liquidity Accounts for bootstrap pool instruction
Fields
pool: Box<Account<'info, Pool>>Pool account (PDA)
lp_mint: Account<'info, Mint>LP token mint of the pool
user_pool_lp: Account<'info, TokenAccount>user pool lp token account. lp will be burned from this account upon success liquidity removal.
a_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault A. Used to receive/burn the vault LP upon deposit/withdraw from the vault.
b_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault B. Used to receive/burn the vault LP upon deposit/withdraw from the vault.
a_vault: Box<Account<'info, Vault>>Vault account for token a. token a of the pool will be deposit / withdraw from this vault account.
b_vault: Box<Account<'info, Vault>>Vault account for token b. token b of the pool will be deposit / withdraw from this vault account.
a_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault a
b_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault b
a_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault A
b_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault B
user_a_token: Account<'info, TokenAccount>User token A account. Token will be transfer from this account if it is add liquidity operation. Else, token will be transfer into this account.
user_b_token: Account<'info, TokenAccount>User token B account. Token will be transfer from this account if it is add liquidity operation. Else, token will be transfer into this account.
user: Signer<'info>User account. Must be owner of user_a_token, and user_b_token.
vault_program: Program<'info, MercurialVault>Vault program. the pool will deposit/withdraw liquidity from the vault.
token_program: Program<'info, Token>Token program.