pub struct RemoveLiquiditySingleSide<'info> {Show 15 fields
pub pool: Box<Account<'info, Pool>>,
pub lp_mint: Account<'info, Mint>,
pub user_pool_lp: Account<'info, TokenAccount>,
pub a_vault_lp: Box<Account<'info, TokenAccount>>,
pub b_vault_lp: Box<Account<'info, TokenAccount>>,
pub a_vault: Box<Account<'info, Vault>>,
pub b_vault: Box<Account<'info, Vault>>,
pub a_vault_lp_mint: Box<Account<'info, Mint>>,
pub b_vault_lp_mint: Box<Account<'info, Mint>>,
pub a_token_vault: Box<Account<'info, TokenAccount>>,
pub b_token_vault: Box<Account<'info, TokenAccount>>,
pub user_destination_token: Account<'info, TokenAccount>,
pub user: Signer<'info>,
pub vault_program: Program<'info, MercurialVault>,
pub token_program: Program<'info, Token>,
}Expand description
Accounts for remove liquidity single sided instruction
Fields
pool: Box<Account<'info, Pool>>Pool account (PDA)
lp_mint: Account<'info, Mint>LP token mint of the pool
user_pool_lp: Account<'info, TokenAccount>User pool lp token account. LP will be burned from this account upon success liquidity removal.
a_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault A. Used to receive/burn the vault LP upon deposit/withdraw from the vault.
b_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault B. Used to receive/burn the vault LP upon deposit/withdraw from the vault.
a_vault: Box<Account<'info, Vault>>Vault account for token A. Token A of the pool will be deposit / withdraw from this vault account.
b_vault: Box<Account<'info, Vault>>Vault account for token B. Token B of the pool will be deposit / withdraw from this vault account.
a_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault A
b_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault B
a_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault A
b_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault B
user_destination_token: Account<'info, TokenAccount>User token account to receive token upon success liquidity removal.
user: Signer<'info>User account. Must be owner of the user_pool_lp account.
vault_program: Program<'info, MercurialVault>Vault program. The pool will deposit/withdraw liquidity from the vault.
token_program: Program<'info, Token>Token program.