pub struct InitializePermissionlessPool<'info> {Show 24 fields
pub pool: Box<Account<'info, Pool>>,
pub lp_mint: Box<Account<'info, Mint>>,
pub token_a_mint: Box<Account<'info, Mint>>,
pub token_b_mint: Box<Account<'info, Mint>>,
pub a_vault: Box<Account<'info, Vault>>,
pub b_vault: Box<Account<'info, Vault>>,
pub a_token_vault: Box<Account<'info, TokenAccount>>,
pub b_token_vault: Box<Account<'info, TokenAccount>>,
pub a_vault_lp_mint: Box<Account<'info, Mint>>,
pub b_vault_lp_mint: Box<Account<'info, Mint>>,
pub a_vault_lp: Box<Account<'info, TokenAccount>>,
pub b_vault_lp: Box<Account<'info, TokenAccount>>,
pub payer_token_a: Box<Account<'info, TokenAccount>>,
pub payer_token_b: Box<Account<'info, TokenAccount>>,
pub payer_pool_lp: Box<Account<'info, TokenAccount>>,
pub admin_token_a_fee: Box<Account<'info, TokenAccount>>,
pub admin_token_b_fee: Box<Account<'info, TokenAccount>>,
pub payer: Signer<'info>,
pub fee_owner: UncheckedAccount<'info>,
pub rent: Sysvar<'info, Rent>,
pub vault_program: Program<'info, MercurialVault>,
pub token_program: Program<'info, Token>,
pub associated_token_program: Program<'info, AssociatedToken>,
pub system_program: Program<'info, System>,
}Expand description
Permissionless Initialize Accounts for initialize new pool instruction
Fields
pool: Box<Account<'info, Pool>>Pool account (PDA address)
lp_mint: Box<Account<'info, Mint>>LP token mint of the pool
token_a_mint: Box<Account<'info, Mint>>Token A mint of the pool. Eg: USDT
token_b_mint: Box<Account<'info, Mint>>Token B mint of the pool. Eg: USDC
a_vault: Box<Account<'info, Vault>>Vault account for token A. Token A of the pool will be deposit / withdraw from this vault account.
b_vault: Box<Account<'info, Vault>>Vault account for token B. Token B of the pool will be deposit / withdraw from this vault account.
a_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault A
b_token_vault: Box<Account<'info, TokenAccount>>Token vault account of vault B
a_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault A
b_vault_lp_mint: Box<Account<'info, Mint>>LP token mint of vault B
a_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault A. Used to receive/burn the vault LP upon deposit/withdraw from the vault.
b_vault_lp: Box<Account<'info, TokenAccount>>LP token account of vault B. Used to receive/burn vault LP upon deposit/withdraw from the vault.
payer_token_a: Box<Account<'info, TokenAccount>>Payer token account for pool token A mint. Used to bootstrap the pool with initial liquidity.
payer_token_b: Box<Account<'info, TokenAccount>>Admin token account for pool token B mint. Used to bootstrap the pool with initial liquidity.
payer_pool_lp: Box<Account<'info, TokenAccount>>CHECK: Payer pool LP token account. Used to receive LP during first deposit (initialize pool)
admin_token_a_fee: Box<Account<'info, TokenAccount>>Admin fee token account for token A. Used to receive trading fee.
admin_token_b_fee: Box<Account<'info, TokenAccount>>Admin fee token account for token B. Used to receive trading fee.
payer: Signer<'info>Admin account. This account will be the admin of the pool, and the payer for PDA during initialize pool.
fee_owner: UncheckedAccount<'info>CHECK: fee owner
rent: Sysvar<'info, Rent>Rent account.
vault_program: Program<'info, MercurialVault>Vault program. The pool will deposit/withdraw liquidity from the vault.
token_program: Program<'info, Token>Token program.
associated_token_program: Program<'info, AssociatedToken>Associated token program.
system_program: Program<'info, System>System program.